[−][src]Struct ipnet::AddrParseError
An error which can be returned when parsing an IP network address.
This error is used as the error type for the FromStr implementation for
IpNet, Ipv4Net, and Ipv6Net.